/**
 * @module calendar
 */
import { JulianDate } from './dates/julianDate';
import { Celestial } from './celestial/index';
import { Naksatra } from './dates/baseDate';
export interface SauraDate {
    sauraMasa: number;
    sauraDivasa: number;
}
export interface WeekDay {
    en: string;
    ml: string;
}
/**
 *
 *  **INTERNAL/PRIVATE**
 *
 * @class Calendar
 */
export declare class Calendar {
    celestial: Celestial;
    constructor(celestial: Celestial);
    static get weekdays(): {
        [key: number]: WeekDay;
    };
    static get months(): {
        [key: string]: number;
    };
    static get naksatras(): {
        [key: number]: Naksatra;
    };
    static timeIntoFractionalDay(date: Date): number;
    static gregorianDateToJulianDay(date: Date): number;
    static julianDayToJulianDate(julianDay: number): JulianDate;
    static julianDayToGregorianDate(julianDay: number): Date;
    static julianDayToModernDate(julianDay: number): (Date | JulianDate);
    static julianDayToAhargana(julianDay: number): number;
    static aharganaToJulianDay(ahargana: number): number;
    static kaliToSaka(yearKali: number): number;
    static sakaToKali(yearSaka: number): number;
    static julianDayToWeekday(julianDay: number): WeekDay;
    static getAdhimasa(lastConjunctionLongitude: number, nextConjunctionLongitude: number): string;
    static getMasaNum(trueSolarLongitude: number, lastConjunctionLongitude: number): number;
    static getNaksatra(trueLunarLongitude: number): Naksatra;
    nextDate(date: Date): Date;
    julianInEngland(julianDay: number): boolean;
    aharganaToKali(ahargana: number): number;
    kaliToAhargana(yearKali: number, masaNum: number, tithiDay: number): number;
    findSamkranti(leftAhargana: number, rightAhargana: number): number;
    calculateSamkranti(ahargana: number, desantara: number): void;
    isTodaySauraMasaFirst(ahargana: number, desantara: number): boolean;
    getSauraMasaAndSauraDivasa(ahargana: number, desantara: number): SauraDate;
}
