/**
 *
 */
export interface Naksatra {
    /**
     *
     */
    readonly saka: string;
    /**
     *
     */
    readonly enMalayalam: string;
    /**
     *
     */
    readonly mlMalayalam: string;
}
/**
 *
 */
export interface MasaName {
    /**
     *
     */
    readonly saka: string;
    /**
     *
     */
    readonly saura: string;
    /**
     *
     */
    readonly enMalayalam: string;
    /**
     *
     */
    readonly mlMalayalam: string;
}
/**
 * Serves as the base class for both the {@link JulianDate} and {@link KollavarshamDate} classes.
 *
 * **INTERNAL/PRIVATE**
 *
 * @class BaseDate
 * @constructor true
 */
export declare abstract class BaseDate {
    /**
     * The year corresponding to this instance of the date.
     *
     * @property year
     * @type {Number}
     */
    year: number;
    /**
     * The month corresponding to this instance of the date.
     *
     * @property month
     * @type {Number}
     */
    month: number;
    /**
     * The date corresponding to this instance of the date.
     *
     * @property date
     * @type {Number}
     */
    date: number;
    /**
     * The gregorian date corresponding to this instance of the date.
     *
     * **Set separately after an instance is created**
     *
     * @property gregorianDate
     * @type {Date}
     */
    gregorianDate: Date;
    /**
     * The `Julian Day` corresponding to this instance of the date.
     *
     * **Set separately after an instance is created**
     * Julian day is the continuous count of days since the beginning of the Julian Period used primarily by astronomers.
     *
     * _Source_: https://en.wikipedia.org/wiki/Julian_day
     *
     * @property julianDay
     * @type {Number}
     */
    julianDay: number;
    /**
     * The `Ahargana` corresponding to this instance of the date. **Set separately after an instance is created**.
     *
     * In Sanskrit `ahoratra` means one full day and `gana` means count.
     * Hence, the Ahargana on any given day stands for the number of lunar days that have elapsed starting from an epoch.
     *
     * _Source_: http://cs.annauniv.edu/insight/Reading%20Materials/astro/sharptime/ahargana.htm
     *
     * @property ahargana
     * @type {Number}
     */
    ahargana: number;
    /**
     * The `Saura Masa` (Solar Calendar Month) for this instance of the date.
     *
     * **Set separately after an instance is created**
     *
     * @property sauraMasa
     * @type {Number}
     */
    sauraMasa: number;
    /**
     * The `Saura Divasa` (Solar Calendar Day) for this instance of the date.
     *
     * **Set separately after an instance is created**
     *
     * @property sauraDivasa
     * @type {Number}
     */
    sauraDivasa: number;
    /**
     * The `Naksatra` (Star) for this instance of the date. **Set separately after an instance is created**
     *
     * @property naksatra
     * @type { { saka: String, enMalayalam: string, mlMalayalam: string } }
     */
    private _naksatra;
    /**
     *
     */
    protected constructor(year?: number, month?: number, date?: number);
    /**
     *
     */
    get naksatra(): Naksatra;
    /**
     *
     */
    set naksatra(val: Naksatra);
    /**
     * Returns the Saura Masa name for the current instance of date.
     *
     * @property sauraMasaName
     * @type {string}
     */
    get sauraMasaName(): string;
    /**
     * Returns the weekday (in English) for the current instance of date.
     *
     * @property weekdayName
     * @type {string}
     */
    get weekdayName(): string;
    /**
     * Returns the weekday (in Malayalam) for the current instance of date.
     *
     * @property mlWeekdayName
     * @type {string}
     */
    get mlWeekdayName(): string;
    /**
     * Converts the Date to a nicely formatted string with year, month and date.
     *
     * @method toString
     * @for BaseDate
     * @type {string}
     */
    toString(): string;
    /**
     * Returns the month names object that has Saka, Saura and Kollavarsham (English & Malayalam) month names for the specified index `masaNumber`.
     *
     * @returns
     * @method getMasaName
     * @for BaseDate
     */
    static getMasaName(masaNumber: number): MasaName;
}
